pub struct DeltaMptKeyPadding(/* private fields */);Expand description
The padding is uniquely generated for DeltaMPT at each intermediate epoch, and it’s used to compute padding bytes for address and storage_key. The padding setup is against an attack where adversary artificially build deep paths in MPT.